@@ -665,6 +665,8 @@ def DrawLine(x, y, angle, **kwargs):
         Determines the width of the arrow head.
     arrow_color : str, optional
         Determines the arrow color.
+    arrow_size : int, optional
+        Determines the arrow size.
 
     Returns
     -------
@@ -690,12 +692,14 @@ def DrawLine(x, y, angle, **kwargs):
     head_width = kwargs.get('head_width')
     if type(head_width) == type(None):
       head_width = 7
+    arrow_size = kwargs.get('arrow_size')
+    if type(arrow_size) == type(None):
+      arrow_size = 10
 
-    r = 10 
     if type(ax) == type(None):
-        return plt.arrow(x, y, r*np.cos(angle), r*np.sin(angle),width = arrow_width,head_width=head_width,fc = arrow_color)
+        return plt.arrow(x, y, arrow_size*np.cos(angle), arrow_size*np.sin(angle),width = arrow_width,head_width=head_width,fc = arrow_color)
     else:
-        return ax.arrow(x, y, r*np.cos(angle), r*np.sin(angle),width = arrow_width,head_width=head_width,fc = arrow_color)
+        return ax.arrow(x, y, arrow_size*np.cos(angle), arrow_size*np.sin(angle),width = arrow_width,head_width=head_width,fc = arrow_color)
 
 def HeadOrientation(data, step, head = "cervical", tail = "tailBase", **kwargs):
     """
@@ -753,6 +757,8 @@ def HeadOrientation(data, step, head = "cervical", tail = "tailBase", **kwargs):
         Determines the width of the arrow head.
     arrow_color : str, optional
         Determines the arrow color.
+    arrow_size : int, optional
+        Determines the arrow size.
 
     Returns
     -------
@@ -809,6 +815,9 @@ def HeadOrientation(data, step, head = "cervical", tail = "tailBase", **kwargs):
     head_width = kwargs.get('head_width')
     if type(head_width) == type(None):
       head_width = 7 
+    arrow_size = kwargs.get('arrow_size')
+    if type(arrow_size) == type(None):
+      arrow_size = 10
 
     values = (data.iloc[2:,1:].values).astype(np.float)
     lista1 = (data.iloc[0][1:].values +" - " + data.iloc[1][1:].values).tolist()
@@ -853,7 +862,7 @@ def HeadOrientation(data, step, head = "cervical", tail = "tailBase", **kwargs):
         plt.yticks(fontsize = fontsize*0.8)
       
         for i in range(0,len(tailY),step):
-            rat.DrawLine(tailX[i], tailY[i], (rad[i]), ax = ax,arrow_color = arrow_color)
+            rat.DrawLine(tailX[i], tailY[i], (rad[i]), ax = ax,arrow_color = arrow_color, arrow_size = arrow_size)
 
         plt.plot([esquerda,esquerda] , [baixo,cima],"k")
         plt.plot([esquerda,direita]  , [cima,cima],"k")
@@ -868,7 +877,7 @@ def HeadOrientation(data, step, head = "cervical", tail = "tailBase", **kwargs):
     else:
         ax.set_aspect('equal')
         for i in range(0,len(tailY),step):
-            rat.DrawLine(tailX[i], tailY[i], (rad[i]), ax =ax,arrow_color = arrow_color)
+            rat.DrawLine(tailX[i], tailY[i], (rad[i]), ax =ax,arrow_color = arrow_color,arrow_size = arrow_size)
         ax.plot([esquerda,esquerda] , [baixo,cima],"k")
         ax.plot([esquerda,direita]  , [cima,cima],"k")
         ax.plot([direita,direita]   , [cima,baixo],"k")
